---
title: Multi-layer perceptrons
---

::: klax.nn.MLP
    options:
        members:
            - __init__
            - __call__

---

::: klax.nn.FICNN
    options:
        members:
            - __init__
            - __call__